==> byteplus_rtc-3.44.1.tar.gz: lib/api/bytertc_audio_mixing_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_audio_defines.dart';

/// AUdio mixing management
///
/// In ios application development, when using audio mixing function, you must call [setActive:withOptions:error:](https://developer.apple.com/documentation/avfaudio/avaudiosession/1616627-setactive?language=objc) to activate the app's audio session. You can deactivate the audio session after quitting audio mixing scenario.
abstract class RTCAudioMixingManager {
  /// Starts mixing audio files.
  ///
  /// [mixId] is used for identifying the mixing task. <br>
  /// If you have already preloaded the file in memory with [RTCAudioMixingManager.preloadAudioMixing], please ensure that the mixID is the same.  <br>
  /// If this API is repeatedly called with the same ID, the previous mixing task will be stopped and a new task will start. When the previous task is stopped, you will receive [RTCVideoEventHandler.onAudioMixingStateChanged].
  ///
  /// [filePath] is the path of the mixing audio file. <br>
  /// <br>You can use the URL of the online file, and the absolute path of the local file. For the URL of the online file, only https protocal is supported. <br>
  /// Audio file formats supported by different platforms are as follows:
  /// <table border>
  /// <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th>
  /// <tr><td>Android</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td>
  /// <tr><td>iOS</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td>
  /// </table>
  /// <br>
  ///
  /// Notes：
  /// + You can call this API with different mixIDs and filePaths to mix multiple audio files at the same time.
  /// + After calling this API, you will receive [RTCVideoEventHandler.onAudioMixingStateChanged] about the current mixing status.<br>
  /// + Call [RTCAudioMixingManager.stopAudioMixing] to stop the mixing task.
  Future<void> startAudioMixing(
      {required int mixId,
      required String filePath,
      required AudioMixingConfig config});

  /// Stops the specified mixing task.
  ///
  /// Notes:
  /// + After calling this API, [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered.
  /// + After calling this API to stop mixing task, the music file will be automatically uninstalled.
  Future<void> stopAudioMixing(int mixId);

  /// Pauses the specified mixing task.
  ///
  /// Notes
  /// + After calling [RTCAudioMixingManager.startAudioMixing] to start playing music files and mixing audios, you can call this API to pause the task. <br>
  /// + Call [RTCAudioMixingManager.resumeAudioMixing] to resume the task.<br>
  /// + After calling this API, [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered.
  Future<void> pauseAudioMixing(int mixId);

  /// Resumes the mixing task that you have paused.
  ///
  /// Notes:
  /// + After calling [RTCAudioMixingManager.pauseAudioMixing], you can call this API to resume the task.<br>
  /// + After calling this API, [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered.
  Future<void> resumeAudioMixing(int mixId);

  /// Preloads the audio file into memory to minimize the loading cost of playing repeatedly.
  ///
  /// If you call [RTCAudioMixingManager.startAudioMixing] first and then call this API with the same ID, the previous mixing task will be stopped, and then the next file will be loaded. <br>
  /// After calling this API to preload A.mp3, if you need to call [RTCAudioMixingManager.startAudioMixing] to play B.mp3 with the same ID, make sure to call [RTCAudioMixingManager.unloadAudioMixing] to unload A.mp3 first.
  ///
  /// You can use the URL of the online file, and the absolute path of the local file. For the URL of the online file, only https protocal is supported. <br>
  /// Audio file formats supported by different platforms are as follows:
  /// <table border>
  /// <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th></tr>
  /// <tr><td>Android</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td></tr>
  /// <tr><td>iOS</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td></tr>
  /// </table>
  ///
  /// Notes:
  /// + You can only perload the audio file of length less than 20s, otherwise the [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered notifying the preloading failure.
  /// + You will also be notified of other states through [RTCVideoEventHandler.onAudioMixingStateChanged].
  /// +  Unload the preloaded file with [RTCAudioMixingManager.unloadAudioMixing].
  Future<void> preloadAudioMixing(
      {required int mixId, required String filePath});

  /// Uninstalls the specified music file.
  ///
  /// Whether the music file is playing or not, after calling this API to uninstall the file, the SDK will call back to notify that the mixing task has stopped. See [RTCVideoEventHandler.onAudioMixingStateChanged].
  Future<void> unloadAudioMixing(int mixId);

  /// Adjusts the mixing volume, including audio files and PCM data.
  ///
  /// [volume] is the ratio of the mixing volume to the original volume. The range is `[0, 400]`. The recommended range is `[0, 100]`.
  /// + 0: Mute
  /// + 100: Original volume(default)
  /// + 400: Maximum volume (with overflow protection)
  ///
  /// Make sure you have called [RTCAudioMixingManager.preloadAudioMixing] or [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> setAudioMixingVolume(
      {required int mixId, required int volume, required AudioMixingType type});

  /// Gets the duration in ms of the music file.
  ///
  /// API call result:
  /// + `>0`: Success, SDK will return the duration of the music file, in milliseconds.
  /// + `<0`: Failure.
  ///
  /// Make sure you have called [RTCAudioMixingManager.preloadAudioMixing] or [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<int?> getAudioMixingDuration(int mixId);

  /// Gets the music file playback progress in ms.
  ///
  /// API call result:
  /// + `>0`: Success, SDK will return the music file playback progress, in milliseconds.
  /// + `<0`: Failure.
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<int?> getAudioMixingCurrentPosition(int mixId);

  /// Sets the starting position of the audio file for audio mixing.
  ///
  /// [position]: The starting position in ms. <br>
  /// You can get the length of the file with [RTCAudioMixingManager.getAudioMixingDuration]. The value of the position must be less than the length of the file.
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> setAudioMixingPosition(
      {required int mixId, required int position});

  /// Sets the channel mode of the current music file. Consistent wih the original file by default.
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> setAudioMixingDualMonoMode(
      {required int mixId, required AudioMixingDualMonoMode mode});

  /// Enables local playback of music files in a different key, mostly used in Karaoke scenarios.
  ///
  /// [pitch] is the value by which the adjusted pitch is raised/lowered from the original pitch, and takes the range [-12, 12], with the default value being 0, i.e. no adjustment is made.<br>
  /// The difference in pitch between two adjacent values within the value range is a semitone, with positive values indicating an ascending tone and negative values indicating a descending tone, and the larger the absolute value you set, the more the pitch is raised or lowered.<br>
  /// Settings outside the range of values will fail and trigger [RTCVideoEventHandler.onAudioMixingStateChanged].
  ///
  /// Notes: Call this API between [RTCAudioMixingManager.startAudioMixing] and [RTCAudioMixingManager.stopAudioMixing].
  Future<void> setAudioMixingPitch({required int mixId, required int pitch});

  /// Sets the playback speed of the current audio file.
  ///
  /// [speed]: Ratio of playback speed to original speed in percentage. The range is [50,200], the default value is 100.  <br>
  /// Settings outside the range of values will fail and trigger [RTCVideoEventHandler.onAudioMixingStateChanged].
  ///
  /// Notes:
  /// + You should call this API after calling [RTCAudioMixingManager.startAudioMixing] and receiving [RTCVideoEventHandler.onAudioMixingStateChanged] indicating that the [AudioMixingState] is `playing` and the [AudioMixingError] is `ok`.  <br>
  /// + If you call this API after calling [RTCAudioMixingManager.stopAudioMixing]or [RTCAudioMixingManager.unloadAudioMixing], you will receive [RTCVideoEventHandler.onAudioMixingStateChanged] indicating that the [AudioMixingState] is `failed` and the [AudioMixingError] is `idNotFound`.
  Future<int?> setAudioMixingPlaybackSpeed(
      {required int mixId, required int speed});

  /// If you need to call [RTCVideo.enableVocalInstrumentBalance] to adjust the volume of the audio file or PCM data used for audio mixing, you must import the original loudness value of the audio file or PCM data via this API.
  ///
  /// [loudness]: Original loudness of the audio file in lufs. The range is [-70.0, 0.0].  <br>
  /// If the value is set to be less than -70.0lufs, it is automatically adjusted to -70.0lufs. If the value is set to be greater than 0.0lufs, SDK will not equalize the loudness. The default value is 1.0lufs, i.e. No loudness equalization effect.
  ///
  /// To avoid sudden volume changes during audio file playback, we recommend that you call this API before starting to play the audio file with [RTCAudioMixingManager.startAudioMixing].
  Future<void> setAudioMixingLoudness(
      {required int mixId, required double loudness});

  /// Sets the interval of callbacks about audio file playback progress during audio mixing.
  ///
  /// You can set the interval for multiple IDs by calling this method multiple times and passing in different [mixId]s.
  ///
  /// [interval] The time interval (ms) of the audio file playback progress callback in milliseconds. <br>
  /// + The value of interval is a multiple of 10 greater than 0. When the value set is not divisible by 10, the default is rounded up by 10. For example, if the value is set to 52ms, it will be automatically adjusted to 60ms, then the SDK will trigger `onAudioMixingPlayingProgress` callback at the set interval.
  /// + If the value is less than or equals to 0, the callback will not be triggered.
  ///
  /// Notes:
  /// + Call this API between [RTCAudioMixingManager.startAudioMixing] and [RTCAudioMixingManager.stopAudioMixing].
  /// + If you want to set the interval of playback progress callbacks before the music file starts playing, you need to call [RTCAudioMixingManager.startAudioMixing] to set the interval in [AudioMixingConfig], and you can update the callback interval through this method after the audio file starts playing.
  Future<void> setAudioMixingProgressInterval(
      {required int mixId, required int interval});

  /// Gets the track index of the current audio file.
  ///
  /// API call result
  /// + `≥0`: Success, SDK will return the track index.
  /// + `<0`:Failure
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<int?> getAudioTrackCount(int mixId);

  /// Specifies the playback track of the current audio file.
  ///
  /// [audioTrackIndex] should be less than or equal to the returned value of [RTCAudioMixingManager.getAudioTrackCount].
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> selectAudioTrack(
      {required int mixId, required int audioTrackIndex});
}

==> byteplus_rtc-3.45.1.tar.gz: lib/api/bytertc_audio_mixing_api.dart <==
// Copyright 2022 BytePlus Pte. Ltd.
// SPDX-License-Identifier: MIT

import 'bytertc_audio_defines.dart';

/// AUdio mixing management
///
/// In ios application development, when using audio mixing function, you must call [setActive:withOptions:error:](https://developer.apple.com/documentation/avfaudio/avaudiosession/1616627-setactive?language=objc) to activate the app's audio session. You can deactivate the audio session after quitting audio mixing scenario.
abstract class RTCAudioMixingManager {
  /// Starts mixing audio files.
  ///
  /// [mixId] is used for identifying the mixing task.
  /// If you have already preloaded the file in memory with [RTCAudioMixingManager.preloadAudioMixing], please ensure that the mixID is the same.
  /// If this API is repeatedly called with the same ID, the previous mixing task will be stopped and a new task will start. When the previous task is stopped, you will receive [RTCVideoEventHandler.onAudioMixingStateChanged].
  ///
  /// [filePath] is the path of the mixing audio file.
  /// You can use the URL of the online file, and the absolute path of the local file. For the URL of the online file, only https protocal is supported.
  /// Recommended audio sample rates: 8KHz, 16KHz, 22.05KHz, 44.1KHz, 48KHz.
  /// Audio file formats supported by different platforms are as follows:
  /// <table border>
  /// <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th>
  /// <tr><td>Android</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td>
  /// <tr><td>iOS</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td>
  /// </table>
  /// <br>
  ///
  /// Notes：
  /// + You can call this API with different mixIDs and filePaths to mix multiple audio files at the same time.
  /// + After calling this API, you will receive [RTCVideoEventHandler.onAudioMixingStateChanged] about the current mixing status.<br>
  /// + Call [RTCAudioMixingManager.stopAudioMixing] to stop the mixing task.
  Future<void> startAudioMixing({
    required int mixId,
    required String filePath,
    required AudioMixingConfig config,
  });

  /// Stops the specified mixing task.
  ///
  /// Notes:
  /// + After calling this API, [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered.
  /// + After calling this API to stop mixing task, the music file will be automatically uninstalled.
  Future<void> stopAudioMixing(int mixId);

  /// Pauses the specified mixing task.
  ///
  /// Notes
  /// + After calling [RTCAudioMixingManager.startAudioMixing] to start playing music files and mixing audios, you can call this API to pause the task. <br>
  /// + Call [RTCAudioMixingManager.resumeAudioMixing] to resume the task.<br>
  /// + After calling this API, [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered.
  Future<void> pauseAudioMixing(int mixId);

  /// Resumes the mixing task that you have paused.
  ///
  /// Notes:
  /// + After calling [RTCAudioMixingManager.pauseAudioMixing], you can call this API to resume the task.<br>
  /// + After calling this API, [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered.
  Future<void> resumeAudioMixing(int mixId);

  /// Preloads the audio file into memory to minimize the loading cost of playing repeatedly.
  ///
  /// If you call [RTCAudioMixingManager.startAudioMixing] first and then call this API with the same ID, the previous mixing task will be stopped, and then the next file will be loaded. <br>
  /// After calling this API to preload A.mp3, if you need to call [RTCAudioMixingManager.startAudioMixing] to play B.mp3 with the same ID, make sure to call [RTCAudioMixingManager.unloadAudioMixing] to unload A.mp3 first.
  ///
  /// You can use the URL of the online file, and the absolute path of the local file. For the URL of the online file, only https protocal is supported. <br>
  /// Audio file formats supported by different platforms are as follows:
  /// <table border>
  /// <tr><th></th><th>mp3</th><th>mp4</th><th>aac</th><th>m4a</th><th>3gp</th><th>wav</th><th>ogg</th></tr>
  /// <tr><td>Android</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td></tr>
  /// <tr><td>iOS</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td><td>Y</td></tr>
  /// </table>
  ///
  /// Notes:
  /// + You can only perload the audio file of length less than 20s, otherwise the [RTCVideoEventHandler.onAudioMixingStateChanged] will be triggered notifying the preloading failure.
  /// + You will also be notified of other states through [RTCVideoEventHandler.onAudioMixingStateChanged].
  /// +  Unload the preloaded file with [RTCAudioMixingManager.unloadAudioMixing].
  Future<void> preloadAudioMixing({
    required int mixId,
    required String filePath,
  });

  /// Uninstalls the specified music file.
  ///
  /// Whether the music file is playing or not, after calling this API to uninstall the file, the SDK will call back to notify that the mixing task has stopped. See [RTCVideoEventHandler.onAudioMixingStateChanged].
  Future<void> unloadAudioMixing(int mixId);

  /// Adjusts the mixing volume, including audio files and PCM data.
  ///
  /// [volume] is the ratio of the mixing volume to the original volume. The range is `[0, 400]`. The recommended range is `[0, 100]`.
  /// + 0: Mute
  /// + 100: Original volume(default)
  /// + 400: Maximum volume (with overflow protection)
  ///
  /// Make sure you have called [RTCAudioMixingManager.preloadAudioMixing] or [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> setAudioMixingVolume({
    required int mixId,
    required int volume,
    required AudioMixingType type,
  });

  /// Gets the duration in ms of the music file.
  ///
  /// API call result:
  /// + `>0`: Success, SDK will return the duration of the music file, in milliseconds.
  /// + `<0`: Failure.
  ///
  /// Make sure you have called [RTCAudioMixingManager.preloadAudioMixing] or [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<int?> getAudioMixingDuration(int mixId);

  /// Gets the music file playback progress in ms.
  ///
  /// API call result:
  /// + `>0`: Success, SDK will return the music file playback progress, in milliseconds.
  /// + `<0`: Failure.
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<int?> getAudioMixingCurrentPosition(int mixId);

  /// Sets the starting position of the audio file for audio mixing.
  ///
  /// [position]: The starting position in ms. <br>
  /// You can get the length of the file with [RTCAudioMixingManager.getAudioMixingDuration]. The value of the position must be less than the length of the file.
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> setAudioMixingPosition({
    required int mixId,
    required int position,
  });

  /// Sets the channel mode of the current music file. Consistent wih the original file by default.
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> setAudioMixingDualMonoMode({
    required int mixId,
    required AudioMixingDualMonoMode mode,
  });

  /// Enables local playback of music files in a different key, mostly used in Karaoke scenarios.
  ///
  /// [pitch] is the value by which the adjusted pitch is raised/lowered from the original pitch, and takes the range [-12, 12], with the default value being 0, i.e. no adjustment is made.<br>
  /// The difference in pitch between two adjacent values within the value range is a semitone, with positive values indicating an ascending tone and negative values indicating a descending tone, and the larger the absolute value you set, the more the pitch is raised or lowered.<br>
  /// Settings outside the range of values will fail and trigger [RTCVideoEventHandler.onAudioMixingStateChanged].
  ///
  /// Notes: Call this API between [RTCAudioMixingManager.startAudioMixing] and [RTCAudioMixingManager.stopAudioMixing].
  Future<void> setAudioMixingPitch({
    required int mixId,
    required int pitch,
  });

  /// Sets the playback speed of the current audio file.
  ///
  /// [speed]: Ratio of playback speed to original speed in percentage. The range is [50,200], the default value is 100.  <br>
  /// Settings outside the range of values will fail and trigger [RTCVideoEventHandler.onAudioMixingStateChanged].
  ///
  /// Notes:
  /// + You should call this API after calling [RTCAudioMixingManager.startAudioMixing] and receiving [RTCVideoEventHandler.onAudioMixingStateChanged] indicating that the [AudioMixingState] is `playing` and the [AudioMixingError] is `ok`.  <br>
  /// + If you call this API after calling [RTCAudioMixingManager.stopAudioMixing]or [RTCAudioMixingManager.unloadAudioMixing], you will receive [RTCVideoEventHandler.onAudioMixingStateChanged] indicating that the [AudioMixingState] is `failed` and the [AudioMixingError] is `idNotFound`.
  Future<int?> setAudioMixingPlaybackSpeed({
    required int mixId,
    required int speed,
  });

  /// If you need to call [RTCVideo.enableVocalInstrumentBalance] to adjust the volume of the audio file or PCM data used for audio mixing, you must import the original loudness value of the audio file or PCM data via this API.
  ///
  /// [loudness]: Original loudness of the audio file in lufs. The range is [-70.0, 0.0].  <br>
  /// If the value is set to be less than -70.0lufs, it is automatically adjusted to -70.0lufs. If the value is set to be greater than 0.0lufs, SDK will not equalize the loudness. The default value is 1.0lufs, i.e. No loudness equalization effect.
  ///
  /// To avoid sudden volume changes during audio file playback, we recommend that you call this API before starting to play the audio file with [RTCAudioMixingManager.startAudioMixing].
  Future<void> setAudioMixingLoudness({
    required int mixId,
    required double loudness,
  });

  /// Sets the interval of callbacks about audio file playback progress during audio mixing.
  ///
  /// You can set the interval for multiple IDs by calling this method multiple times and passing in different [mixId]s.
  ///
  /// [interval] The time interval (ms) of the audio file playback progress callback in milliseconds. <br>
  /// + The value of interval is a multiple of 10 greater than 0. When the value set is not divisible by 10, the default is rounded up by 10. For example, if the value is set to 52ms, it will be automatically adjusted to 60ms, then the SDK will trigger `onAudioMixingPlayingProgress` callback at the set interval.
  /// + If the value is less than or equals to 0, the callback will not be triggered.
  ///
  /// Notes:
  /// + Call this API between [RTCAudioMixingManager.startAudioMixing] and [RTCAudioMixingManager.stopAudioMixing].
  /// + If you want to set the interval of playback progress callbacks before the music file starts playing, you need to call [RTCAudioMixingManager.startAudioMixing] to set the interval in [AudioMixingConfig], and you can update the callback interval through this method after the audio file starts playing.
  Future<void> setAudioMixingProgressInterval({
    required int mixId,
    required int interval,
  });

  /// Gets the track index of the current audio file.
  ///
  /// API call result
  /// + `≥0`: Success, SDK will return the track index.
  /// + `<0`:Failure
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<int?> getAudioTrackCount(int mixId);

  /// Specifies the playback track of the current audio file.
  ///
  /// [audioTrackIndex] should be less than or equal to the returned value of [RTCAudioMixingManager.getAudioTrackCount].
  ///
  /// Make sure you have called [RTCAudioMixingManager.startAudioMixing] before calling this API.
  Future<void> selectAudioTrack({
    required int mixId,
    required int audioTrackIndex,
  });
}
